define(
//begin v1.x content
({
	insertTableTitle: "‏ادراج جدول‏",
	modifyTableTitle: "تعديل جدول",
	rows: "الصفوف:",
	columns: "الأعمدة:",
	align: "محاذاة:",
	cellPadding: "ملء الخانة:",
	cellSpacing: "تباعد الخانة:",
	tableWidth: "عرض الجدول:",
	backgroundColor: "لون الخلفية:",
	borderColor: "لون الحدود:",
	borderThickness: "سمك الحدود",
	percent: "نسبة مئوية",
	pixels: "عنصر صورة",
	"default": "المفترض",
	left: "لليسار",
	center: "توسيط",
	right: "لليمين",
	buttonSet: "تحديد", // translated elsewhere?
	buttonInsert: "‏ادراج‏",
	buttonCancel: "الغاء",

	selectTableLabel: "تحديد جدول",
	insertTableRowBeforeLabel: "اضافة صف قبل",
	insertTableRowAfterLabel: "اضافة صف بعد",
	insertTableColumnBeforeLabel: "اضافة عمود قبل",
	insertTableColumnAfterLabel: "اضافة عمود بعد",
	deleteTableRowLabel: "حذف صف",
	deleteTableColumnLabel: "حذف عمود"
})
//end v1.x content
);
